
%**************************************************************************
% Programm noise_suppression_demo_main
%
% Author:              Gerhard Schmidt, CAU Digital Signal Processing and
%                      System Theory
% Date of generation:  December, 26, 2005
% Project:             noise_suppression_demo
%
% 
% Input: 
%
% Output:               ---
%
%**************************************************************************


%**************************************************************************
% Set path to subdirectories
%**************************************************************************
 
addpath([pwd,'/subfunctions']);
addpath([pwd,'/images']);
addpath([pwd,'/signals']);

%**************************************************************************
% Main data_struct
%**************************************************************************

dim.main_fig.orig_x                        =   12;
dim.main_fig.orig_y                        =   45;
dim.main_fig.width                         = 1000;
dim.main_fig.height                        =  670;
dim.main_fig.space_lr                      =   30; 
dim.main_fig.space_tb                      =   30;
dim.main_fig.af_logo.width                 =  342;
dim.main_fig.af_logo.height                =   48;
dim.main_fig.low_frame.height              =   48;
dim.main_fig.low_frame.button.width        =  140;
dim.main_fig.low_frame.button.height       =   32;
dim.main_fig.low_frame.button.delta_w      =   30;
dim.main_fig.low_frame.checkbox.width      =  100;
dim.main_fig.left_frame.width.small        =  200;
dim.main_fig.left_frame.width.large        =  700;
dim.main_fig.left_frame.space_lr           =   10;
dim.main_fig.left_frame.space_lr_sm        =   10;
dim.main_fig.left_frame.space_tb           =   10;
dim.main_fig.left_frame.space_tb_sm        =    2;
dim.main_fig.left_frame.button.height      =   25;
dim.main_fig.left_frame.button.text_offset =    4;
dim.main_fig.axes.space_left               =   60;
dim.main_fig.axes.space_bottom             =   30;
dim.main_fig.axes.space_delta              =   16;

fonts.normal.size      =  9;
fonts.upper_frame.size = 12;
fonts.small.size       =  9;

[main_data.signals.s main_data.f_s] = wavread('speech.wav');
[main_data.signals.b main_data.f_s] = wavread('car_noise.wav');
main_data.signals.s      = main_data.signals.s / (max(abs(main_data.signals.s))+eps) * 0.8;
main_data.signals.SNR    = 10;
main_data.signals.b      = main_data.signals.b / (std(main_data.signals.b)+eps) * std(main_data.signals.s);
main_data.signals.y      = main_data.signals.s + 10^(-main_data.signals.SNR/20) * main_data.signals.b;
main_data.signals.s_dach = zeros(size(main_data.signals.s));
main_data.N_FFT          = 256;
main_data.frameshift     =  64;
main_data.max_att        =  20;
main_data.overest        =   1;


main_data.axes_top.plot_method            = 'y_time';
main_data.axes_top.plot_handle_1          = 0;
main_data.axes_top.plot_handle_2          = 0;
main_data.axes_top.index                  = 0;
main_data.axes_top.plot_method_changed    = 0;
main_data.axes_bottom.plot_method         = 's_dach_time';
main_data.axes_bottom.plot_handle_1       = 0;
main_data.axes_bottom.plot_handle_2       = 0;
main_data.axes_bottom.index               = 0;
main_data.axes_bottom.plot_method_changed = 0;

main_data.sim_active = 0;
main_data.auto_mode  = 1;

%******************************************************************
% User interface
%******************************************************************

load noise_suppression_demo_main;

a = figure('Units','pixels', ...
           'Color',[0.85 0.85 0.85], ...
           'Colormap',mat0, ...
           'Name','Adaptive Filters - Demo Noise Suppression', ...         
	       'NumberTitle','off', ...
           'PointerShapeCData',mat1, ...
	       'Position',[dim.main_fig.orig_x dim.main_fig.orig_y dim.main_fig.width dim.main_fig.height], ...
           'UserData',main_data, ...
           'Tag','demo_ns_main_fig');                  
      
%******************************************************************
% Title frame
%******************************************************************       
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','image(logo_adaptive_filters); axis tight; set(gca,''XTick'',[],''YTick'',[]);', ...
	     'Position',[dim.main_fig.space_lr dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	     'Tag','demo_ns_axes_logo');

b = uicontrol('Parent',a, ...                       
	          'Units','pixels', ...                   
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr) dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	          'Style','frame', ...
              'Tag','demo_ns_uppper_frame'); 
                                                      
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.9 0.9 0.9], ...   
	          'HorizontalAlignment','center', ...
              'FontWeight','bold', ...
              'FontSize',fonts.upper_frame.size, ...
	          'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr)+5 dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height+12 dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width-10 20], ...
	          'String','Demo - Noise Suppression', ...
	          'Style','text');  
                   
%******************************************************************
% Left frame (visible)
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height dim.main_fig.left_frame.width.small dim.main_fig.height-(4*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.low_frame.height ], ...
	          'Style','frame', ...
              'Tag','demo_ns_main_left_frame');           
                    
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','ns_reduce_frame_left(dim)', ...             
	          'String','<<', ...
              'TooltipString','Hides a picture that shows the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_ns_reduce_left_frame');

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+round((dim.main_fig.left_frame.width.small+dim.main_fig.left_frame.space_lr)/2) dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','ns_enlarge_frame_left(dim);', ...             
	          'String','>>', ...
              'TooltipString','Shows a picture that depicts the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_ns_enlarge_left_frame');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(4*dim.main_fig.left_frame.space_tb)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+(3*dim.main_fig.left_frame.space_tb_sm)+dim.main_fig.left_frame.space_tb], ...
	          'Style','frame', ...
              'Tag','demo_ns_main_left_frame_visualizations');            
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Visualizations:', ...
	          'Tag','demo_ns_main_left_frame_text_visualization', ...
              'Style','text');            
                           
b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 1: s(n) - time ana.','Plot 1: s(n) - spectrogram','Plot 1: y(n) - time ana.','Plot 1: y(n) - spectrogram','Plot 1: \hat s(n) - time ana.','Plot 1: \hat s(n) - spectrogram'}, ...
              'FontWeight','bold', ...
              'Value',3, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); ns_set_plot(x,1);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-dim.main_fig.left_frame.space_tb_sm-(3*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the upper diagram.',...
              'Style','popupmenu', ...  
              'Tag','demo_ns_main_left_frame_plot_axes_top');

b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 2: s(n) - time ana.','Plot 2: s(n) - time-frequency ana.','Plot 2: y(n) - time ana.','Plot 2: y(n) - time-frequency ana.','Plot 2: Output - time ana.','Plot 2: Output - time-frequency ana.'}, ...
              'FontWeight','bold', ...
              'Value',5, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); ns_set_plot(x,2);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the lower diagram.',...
              'Style','popupmenu', ...  
              'Tag','demo_ns_main_left_frame_plot_axes_bottom');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.space_tb_sm)-(7*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+2*dim.main_fig.left_frame.space_tb+(6*dim.main_fig.left_frame.space_tb_sm)], ...
	          'Style','frame', ...
              'Tag','demo_ns_main_left_frame_visualizations');           
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(5*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Signals:', ...
	          'Tag','demo_ns_main_left_frame_text_signals', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Desired:', ...
	          'Tag','demo_ns_main_left_frame_text_signals_excitation_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','speech', ...
	          'Tag','demo_ns_main_left_frame_text_signals_excitation_right', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(7*dim.main_fig.left_frame.button.height)-(1*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Distortion:', ...
	          'Tag','demo_ns_main_left_frame_text_signals_excitation_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(7*dim.main_fig.left_frame.button.height)-(1*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','car noise', ...
	          'Tag','demo_ns_main_left_frame_text_signals_excitation_right', ...
              'Style','text');            

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(4*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','SNR:', ...
	          'Tag','demo_ns_main_left_frame_text_para_order_left', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(4*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',num2str(main_data.signals.SNR), ...
              'Callback','main_data = get(gcf,''UserData''); main_data.signals.SNR = str2num(get(gco,''String'')); set(gcf,''UserData'',main_data); ns_start_sim;', ...
	          'TooltipString','Sets the signal-to-noise ratio. Values are in dB!',...
              'Tag','demo_ns_main_left_frame_edit_para_order_right', ...
              'Style','edit');           
          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(8*dim.main_fig.left_frame.space_tb)-(3*dim.main_fig.left_frame.space_tb_sm)-(11*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+(2*dim.main_fig.left_frame.space_tb)], ...
	          'Style','frame', ...
              'Tag','demo_ns_main_left_frame_control_para');   
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(9*dim.main_fig.left_frame.button.height)-(6*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Filter parameters:', ...
	          'Tag','demo_ns_main_left_frame_text_control_parameters', ...
              'Style','text');            

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(10*dim.main_fig.left_frame.button.height)-(6*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Max att.:', ...
	          'Tag','demo_ns_main_left_frame_text_para_order_left', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(10*dim.main_fig.left_frame.button.height)-(6*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',num2str(main_data.max_att), ...
              'Callback','main_data = get(gcf,''UserData''); main_data.max_att = str2num(get(gco,''String'')); set(gcf,''UserData'',main_data); ns_start_sim;', ...
	          'TooltipString','Sets the maximum attenuation of the noise suppression filter. Values are in dB!',...
              'Tag','demo_ns_main_left_frame_edit_para_order_right', ...
              'Style','edit');           

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(11*dim.main_fig.left_frame.button.height)-(6*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Overest.:', ...
	          'Tag','demo_ns_main_left_frame_text_para_order_left', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(11*dim.main_fig.left_frame.button.height)-(6*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',num2str(main_data.overest), ...
              'Callback','main_data = get(gcf,''UserData''); main_data.overest = str2num(get(gco,''String'')); set(gcf,''UserData'',main_data); ns_start_sim;', ...
	          'TooltipString','Sets the overestimation factor of the noise suppression filter',...
              'Tag','demo_ns_main_left_frame_edit_para_order_right', ...
              'Style','edit');              
                           
%******************************************************************
% Left frame (hidden)
%******************************************************************              
 
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
         'Visible','off', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','set(gca,''XTick'',[],''YTick'',[]);', ...         
	     'Position',[2*dim.main_fig.space_lr+dim.main_fig.left_frame.width.small  (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height 1 dim.main_fig.height-(4*dim.main_fig.space_tb)-(2*dim.main_fig.af_logo.height)], ...
	     'Tag','demo_ns_axes_hidden'); 

%******************************************************************
% Main axes (top)
%******************************************************************              
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...     
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left round(dim.main_fig.height/2)+dim.main_fig.axes.space_bottom+round(dim.main_fig.axes.space_delta/2)  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-round(dim.main_fig.height/2)-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_ns_axes_top');              

ns_plot_init(1);     
                  
%******************************************************************
% Main axes (bottom)
%******************************************************************     
     
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...      
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+dim.main_fig.axes.space_bottom  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left round(dim.main_fig.height/2)-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_ns_axes_bottom');                                     
            
%******************************************************************
% Lower frame
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr dim.main_fig.space_tb dim.main_fig.width-(2*dim.main_fig.space_lr) dim.main_fig.low_frame.height], ...
	          'Style','frame', ...
              'Tag','demo_ns_lower_frame');           
          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.width-dim.main_fig.left_frame.space_lr-dim.main_fig.low_frame.button.delta_w-dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...  
              'Callback','q_dlg = questdlg(''Do you really want to close the application?'',''Adaptive Filters - Demo Noise Suppression'',''Yes'',''No'',''Cancel'',''Yes''); if strcmp(q_dlg,''Yes''),close(gcf);end;', ...             
	          'String','Close', ...
              'FontWeight','bold', ... 
              'TooltipString','Click here to close the application!',...
              'Tag','demo_ns_button_close');      
                                              
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','ns_play_speech_signal;', ...
	          'String','Play speech signal', ...
              'FontWeight','bold', ...     
              'TooltipString','Plays the clean speech signal!',...
              'Tag','demo_ns_button_play_speech');  
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+2*dim.main_fig.left_frame.space_lr+dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','ns_play_input_signal;', ...
	          'String','Play noisy input', ...
              'FontWeight','bold', ...     
              'TooltipString','Plays the noisy input signal!',...
              'Tag','demo_ns_button_play_mic');          
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+3*dim.main_fig.left_frame.space_lr+2*dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','ns_play_output_signal;', ...
	          'String','Play output signal', ...
              'FontWeight','bold', ...     
              'TooltipString','Plays the output signal!',...
              'Tag','demo_ns_button_play_output');    
                                  
ns_start_sim;          

% %******************************************************************
% % Allow resizing of the figure
% %******************************************************************          
%              
% ui_cons = findobj('Parent',a);
% for n = 1:length(ui_cons)
%     set(ui_cons(n),'Units','Normalized');
% end;
%           